@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-persist.h,v 1.20 2005/01/08 19:41:46 chpe Exp $
+ *  $Id: ephy-embed-persist.h,v 1.21 2005/02/26 22:01:48 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_PERSIST_H
@@ -105,6 +105,8 @@ void			 ephy_embed_persist_set_persist_key	(EphyEmbedPersist *persist,
 
 void			 ephy_embed_persist_set_source		(EphyEmbedPersist *persist,
 								 const char *value);
+void			 ephy_embed_persist_set_user_time	(EphyEmbedPersist *persist,
+								 guint32 user_time);
 
 const char 		*ephy_embed_persist_get_dest		(EphyEmbedPersist *persist);
 
@@ -122,6 +124,8 @@ const char 		*ephy_embed_persist_get_persist_key	(EphyEmbedPersist *persist);
 
 const char 		*ephy_embed_persist_get_source		(EphyEmbedPersist *persist);
 
+guint32			 ephy_embed_persist_get_user_time	(EphyEmbedPersist *persist);
+
 char			*ephy_embed_persist_to_string		(EphyEmbedPersist *persist);
 
 G_END_DECLS
