@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-debug.h,v 1.8 2004/11/02 20:57:20 chpe Exp $
+ *  $Id: ephy-debug.h,v 1.9 2005/01/28 22:24:02 chpe Exp $
  */
 
 #ifndef EPHY_DEBUG_H
@@ -32,13 +32,25 @@ G_BEGIN_DECLS
 #define DISABLE_PROFILING
 #endif
 
+#if defined(G_HAVE_GNUC_VARARGS)
+
 #ifdef DISABLE_LOGGING
-#define LOG(msg, args...)
+#define LOG(msg, args...) G_STMT_START { } G_STMT_END
 #else
-#define LOG(msg, args...)						\
-g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,				\
-       "[ %s ] " msg,						\
-       __FILE__ , ## args);
+#define LOG(msg, args...)			\
+g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,		\
+       "[ %s ] " msg,				\
+       __FILE__ , ## args)
+#endif
+
+#elif defined(G_HAVE_ISO_VARARGS)
+
+#define LOG(...) G_STMT_START { } G_STMT_END
+
+#else /* no varargs macros */
+
+static void LOG(const char *format, ...) {}
+
 #endif
 
 #ifdef DISABLE_PROFILING
