@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks-import.c,v 1.40 2005/01/19 21:39:01 chpe Exp $
+ *  $Id: ephy-bookmarks-import.c,v 1.42 2005/02/26 22:30:20 chpe Exp $
  */
 
 #include "config.h"
@@ -75,7 +75,7 @@ ephy_bookmarks_import (EphyBookmarks *bookmarks,
 
 	type = gnome_vfs_get_file_mime_type (filename, NULL, FALSE);
 
-	LOG ("Importing bookmarks of type %s", type ? type : "(null)")
+	LOG ("Importing bookmarks of type %s", type ? type : "(null)");
 
 	if (type == NULL)
 	{
@@ -313,9 +313,9 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_fold
 
 			ret = xbel_parse_bookmark (eb, reader, &node);
 
-			keyword = ephy_bookmarks_find_keyword (eb, folder, FALSE);
+			keyword = ephy_bookmarks_find_keyword (eb, folder ? folder : "", FALSE);
 			
-			if (keyword == NULL)
+			if (keyword == NULL && folder != NULL && folder[0] != '\0')
 			{
 				keyword = ephy_bookmarks_add_keyword (eb, folder);
 			}
@@ -332,7 +332,7 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_fold
 		{
 			if (type == XML_READER_TYPE_ELEMENT)
 			{
-				ret = xbel_parse_folder (eb, reader, folder);
+				ret = xbel_parse_folder (eb, reader, folder ? folder : "");
 				
 				if (ret != 1) break;
 			}
